@@ -1,9 +1,9 @@
 import argparse
 import random
 
-from Grid import Grid
-from O import O
-from X import X
+from sudden_appearance_tictactoe.Grid import Grid
+from sudden_appearance_tictactoe.O import O
+from sudden_appearance_tictactoe.X import X
 
 
 def run():
